@@ -75,6 +75,9 @@ gchar		*fwupd_remote_build_firmware_uri	(FwupdRemote	*self,
 gboolean	 fwupd_remote_load_signature		(FwupdRemote	*self,
 							 const gchar	*filename,
 							 GError		**error);
+gboolean	 fwupd_remote_load_signature_bytes	(FwupdRemote	*self,
+							 GBytes		*bytes,
+							 GError		**error);
 
 FwupdRemote	*fwupd_remote_from_variant		(GVariant	*value);
 GPtrArray	*fwupd_remote_array_from_variant	(GVariant	*value);
